==> xfe_0.66.orig.tar.gz: xfe-0.66/src/HistInputDialog.cc <==
// Input dialog with history list and an optional check box

#include "config.h"
#include "i18n.h"

#include <fox/fx.h>
#include <fox/fxkeys.h>

#include "HistInputDialog.h"


// Object implementation
FXIMPLEMENT(MyComboBox,FXComboBox,NULL,0)

MyComboBox::MyComboBox(FXComposite *p,FXint cols,FXint nvis,FXObject* tgt,FXSelector sel,FXuint opts):
        FXComboBox(p,cols,nvis,tgt,sel,opts)
{}
FXDEFMAP(HistInputDialog) HistInputDialogMap[]={
            FXMAPFUNC(SEL_KEYPRESS,0,HistInputDialog::onCmdKeyPress),
        };
// Object implementation
FXIMPLEMENT(HistInputDialog,DialogBox,HistInputDialogMap,ARRAYNUMBER(HistInputDialogMap))

// Construct a dialog box with an optional check box
HistInputDialog::HistInputDialog(FXWindow* w,FXString& inp,FXString message,FXString title,FXString label,FXIcon *ic, int option, FXString optiontext):
        DialogBox(w,title,DECOR_TITLE|DECOR_BORDER)
{
    // Buttons
    buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
    
	// Cancel
    new FXButton(buttons,_("&Cancel"),NULL,this,ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
    
	// Accept
    new FXButton(buttons,_("&Accept"),NULL,this,ID_ACCEPT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);

	// Separator
    new FXHorizontalSeparator(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE);
    
	// Optional check box
	checkbutton=new FXHorizontalFrame(this,JUSTIFY_RIGHT|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,0,0);
	//buttons2=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
    
	if (option)
        new FXCheckButton(checkbutton,optiontext,this,ID_TOGGLE_OPTION);
    

    FXMatrix *matrix = new FXMatrix(this,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
    
	// Icon
    new FXLabel(matrix,"",ic,LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
    
	// Message
    new FXLabel(matrix,message,NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);

    // Label
    new FXLabel(matrix,label,NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
    
	// Input Field
    input = new MyComboBox(matrix,30,5,NULL,0,COMBOBOX_NO_REPLACE|LAYOUT_CENTER_Y|LAYOUT_CENTER_X|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
    input->setText(inp);
}

void HistInputDialog::create()
{
    DialogBox::create();
}

void HistInputDialog::CursorEnd()
{
    input->CursorEnd();
}

void HistInputDialog::SelectAll()
{
    input->onFwdToText(this,MKUINT(0,SEL_FOCUSIN),NULL);
    input->onFwdToText(this,MKUINT(FXTextField::ID_SELECT_ALL,SEL_COMMAND),NULL);
    return;
}

long HistInputDialog::onCmdKeyPress(FXObject* sender,FXSelector sel,void* ptr)
{
    FXEvent* event=(FXEvent*)ptr;
    switch(event->code)
    {
    case KEY_Escape:
        handle(this,MKUINT(ID_CANCEL,SEL_COMMAND),NULL);
		return 1;
    case KEY_KP_Enter:
    case KEY_Return:
        handle(this,MKUINT(ID_ACCEPT,SEL_COMMAND),NULL);
		return 1;
    default:
        FXTopWindow::onKeyPress(sender,sel,ptr);
		return 1;
    }
	return 0;
}

==> xfe_0.72.orig.tar.gz: xfe-0.72/src/HistInputDialog.cc <==
// Input dialog with history list and an optional check box

#include "config.h"
#include "i18n.h"

#include <fox-1.2/fx.h>
#include <fox-1.2/fxkeys.h>

#include "HistInputDialog.h"


// Object implementation
FXIMPLEMENT(MyComboBox,FXComboBox,NULL,0)

MyComboBox::MyComboBox(FXComposite *p,FXint cols,FXObject* tgt,FXSelector sel,FXuint opts):
        FXComboBox(p,cols,tgt,sel,opts)
{}
FXDEFMAP(HistInputDialog) HistInputDialogMap[]={
            FXMAPFUNC(SEL_KEYPRESS,0,HistInputDialog::onCmdKeyPress),
        };
// Object implementation
FXIMPLEMENT(HistInputDialog,DialogBox,HistInputDialogMap,ARRAYNUMBER(HistInputDialogMap))

// Construct a dialog box with an optional check box
HistInputDialog::HistInputDialog(FXWindow* w,FXString& inp,FXString message,FXString title,FXString label,FXIcon *ic, int option, FXString optiontext):
        DialogBox(w,title,DECOR_TITLE|DECOR_BORDER)
{
    // Buttons
    buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,5,5);
    
	// Accept
    new FXButton(buttons,_("&Accept"),NULL,this,ID_ACCEPT,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);

	// Cancel
    new FXButton(buttons,_("&Cancel"),NULL,this,ID_CANCEL,FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT,0,0,0,0,20,20);
    
	// Separator
    new FXHorizontalSeparator(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE);
    
	// Optional check box
	checkbutton=new FXHorizontalFrame(this,JUSTIFY_RIGHT|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0,10,10,0,0);
	//buttons2=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
    
	if (option)
        new FXCheckButton(checkbutton,optiontext,this,ID_TOGGLE_OPTION);
    

    FXMatrix *matrix = new FXMatrix(this,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
    
	// Icon
    new FXLabel(matrix,"",ic,LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
    
	// Message
    new FXLabel(matrix,message,NULL,JUSTIFY_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);

    // Label
    new FXLabel(matrix,label,NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
    
	// Input Field
    input = new MyComboBox(matrix,30,NULL,0,COMBOBOX_NO_REPLACE|LAYOUT_CENTER_Y|LAYOUT_CENTER_X|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
  	input->setNumVisible(5);
    input->setText(inp);
}

void HistInputDialog::create()
{
    DialogBox::create();
}

void HistInputDialog::CursorEnd()
{
    input->CursorEnd();
}

void HistInputDialog::SelectAll()
{
    input->onFwdToText(this,FXSEL(SEL_FOCUSIN,0),NULL);
    input->onFwdToText(this,FXSEL(SEL_COMMAND,FXTextField::ID_SELECT_ALL),NULL);
    return;
}

long HistInputDialog::onCmdKeyPress(FXObject* sender,FXSelector sel,void* ptr)
{
    FXEvent* event=(FXEvent*)ptr;
    switch(event->code)
    {
    case KEY_Escape:
        handle(this,FXSEL(SEL_COMMAND,ID_CANCEL),NULL);
		return 1;
    case KEY_KP_Enter:
    case KEY_Return:
        handle(this,FXSEL(SEL_COMMAND,ID_ACCEPT),NULL);
		return 1;
    default:
        FXTopWindow::onKeyPress(sender,sel,ptr);
		return 1;
    }
	return 0;
}
